<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="120"/>
        <source>Deepin Movie</source>
        <translation>深度影院</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>深度影院是一款设计精良、功能全面的视频播放器，无边框简洁设计，支持多种视频格式本地播放和流媒体播放。</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>此文件夹无效</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open Folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>此文件夹没有操作权限</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>自动查找相似文件连续播放</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>退出深度影院时清空播放列表</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>鼠标悬停进度条时显示预览</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>允许同时运行多个深度影院</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>最小化时暂停</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>自动从上次停止位置播放</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>保存路径</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>基础设置</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>画面/声音</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>字幕</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>字体样式</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>恢复默认</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>打开下一个</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>打开上一个</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>迷你模式</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>Next frame</source>
        <translation>下一帧</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Previous frame</source>
        <translation>上一帧</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>volume down</source>
        <translation>减小音量</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Volume up</source>
        <translation>增大音量</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Speed up</source>
        <translation>加速播放</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Speed down</source>
        <translation>减速播放</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Pause/Play</source>
        <translation>暂停/播放</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Reset speed</source>
        <translation>还原播放速度</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Rewind</source>
        <translation>快退</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Forward</source>
        <translation>快进</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>Burst screenshot</source>
        <translation>连拍截图</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>Film screenshot</source>
        <translation>影片截图</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>0.5s backward</source>
        <translation>字幕延迟0.5秒</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>0.5s forward</source>
        <translation>字幕提前0.5秒</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="45"/>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="46"/>
        <source>Font Size</source>
        <translation>字号</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>请输入您要播放文件的网络地址：</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="269"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light Theme</source>
        <translation>浅色主题</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>置顶窗口</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="284"/>
        <source>Film info</source>
        <translation>电影信息</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open Folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>打开URL</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>播放光盘</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>迷你模式</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>播放模式</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>顺序播放</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>随机播放</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>单个播放</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>单个循环</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>列表循环</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>画面</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="144"/>
        <source>Next frame</source>
        <translation>下一帧</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="145"/>
        <source>Previous frame</source>
        <translation>上一帧</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="152"/>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Channel</source>
        <translation>声道</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="158"/>
        <source>Stereo</source>
        <translation>立体声</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="159"/>
        <source>Left channel</source>
        <translation>左声道</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="160"/>
        <source>Right channel</source>
        <translation>右声道</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="166"/>
        <source>Track</source>
        <translation>音轨</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="176"/>
        <source>Subtitle</source>
        <translation>字幕</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="177"/>
        <source>Load</source>
        <translation>载入字幕</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Online Search</source>
        <translation>查找在线字幕</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Select</source>
        <translation>选择字幕</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Hide</source>
        <translation>隐藏字幕</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="190"/>
        <source>Encodings</source>
        <translation>编码</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="258"/>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="259"/>
        <source>Film Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="260"/>
        <source>Burst Shooting</source>
        <translation>连拍截图</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="267"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="268"/>
        <source>Film Info</source>
        <translation>电影信息</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="282"/>
        <source>Clear playlist</source>
        <translation>清空播放列表</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="283"/>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>duration: %1</source>
        <translation>时长：%1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>resolution: %1</source>
        <translation>分辨率：%1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>size: %1</source>
        <translation>影片大小：%1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>save</source>
        <translation>保存</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="785"/>
        <location filename="../common/mainwindow.cpp" line="2284"/>
        <location filename="../common/mainwindow.cpp" line="2381"/>
        <source>Deepin Movie</source>
        <translation>深度影院</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Load successfully</source>
        <translation>载入字幕成功</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Load failed</source>
        <translation>载入字幕失败</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1392"/>
        <source>No device found</source>
        <translation>没有发现可播放设备</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1410"/>
        <source>Parse Failed</source>
        <translation>解析失败</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1417"/>
        <source>Open Folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1432"/>
        <location filename="../common/mainwindow.cpp" line="1449"/>
        <location filename="../common/mainwindow.cpp" line="1784"/>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1434"/>
        <location filename="../common/mainwindow.cpp" line="1451"/>
        <source>All videos (%1)</source>
        <translation>所有视频(%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1652"/>
        <source>Muted</source>
        <translation>静音</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1655"/>
        <location filename="../common/mainwindow.cpp" line="1667"/>
        <location filename="../common/mainwindow.cpp" line="1677"/>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <source>Volume: %1%</source>
        <translation>音量：%1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1749"/>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <source>Subtitle %1: %2s</source>
        <translation>字幕%1：%2秒</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1750"/>
        <location filename="../common/mainwindow.cpp" line="1758"/>
        <source>delayed</source>
        <translation>延迟</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1750"/>
        <location filename="../common/mainwindow.cpp" line="1758"/>
        <source>advanced</source>
        <translation>提前</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <location filename="../common/mainwindow.cpp" line="1772"/>
        <location filename="../common/mainwindow.cpp" line="1779"/>
        <source>Speed: %1x</source>
        <translation>播放速度：%1倍</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1786"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
        <translation>字幕文件 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1848"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1859"/>
        <source>Movie Screenshot</source>
        <translation>视频截图</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1860"/>
        <source>Saved to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1874"/>
        <location filename="../common/mainwindow.cpp" line="1957"/>
        <source>The screenshot is saved</source>
        <translation>截图已保存</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1874"/>
        <source>The screenshot is failed to save</source>
        <translation>截图保存失败</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2044"/>
        <location filename="../common/mainwindow.cpp" line="2741"/>
        <source>Invalid file: %1</source>
        <translation>无效文件：%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>文件类型：</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>分辨率：</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>文件大小：</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>媒体时长：</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>文件路径：</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1029"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1047"/>
        <source>[internal]</source>
        <translation>【内部】</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>文件不存在</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/深度影院%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/深度影院%2（%3）.jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>上一个</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>下一个</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>字幕</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>播放/暂停</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
</context>
</TS>